@@ -502,7 +502,17 @@ class CfnInclude(
         :param preserve_logical_ids: Whether the resources should have the same logical IDs in the resulting CDK template as they did in the original CloudFormation template file. If you're vending a Construct using an existing CloudFormation template, make sure to pass this as ``false``. **Note**: regardless of whether this option is true or false, the {@link CfnInclude.getResource} and related methods always uses the original logical ID of the resource/element, as specified in the template file. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                template_file: builtins.str,
+                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                preserve_logical_ids: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnIncludeProps(
@@ -526,7 +536,9 @@ class CfnInclude(
         :param condition_name: the name of the Condition in the CloudFormation template file.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_condition)
+            def stub(condition_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument condition_name", value=condition_name, expected_type=type_hints["condition_name"])
         return typing.cast(aws_cdk.core.CfnCondition, jsii.invoke(self, "getCondition", [condition_name]))
 
@@ -542,7 +554,9 @@ class CfnInclude(
         :param hook_logical_id: the logical ID of the Hook in the included CloudFormation template's 'Hooks' section.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_hook)
+            def stub(hook_logical_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument hook_logical_id", value=hook_logical_id, expected_type=type_hints["hook_logical_id"])
         return typing.cast(aws_cdk.core.CfnHook, jsii.invoke(self, "getHook", [hook_logical_id]))
 
@@ -558,7 +572,9 @@ class CfnInclude(
         :param mapping_name: the name of the Mapping in the template to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_mapping)
+            def stub(mapping_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument mapping_name", value=mapping_name, expected_type=type_hints["mapping_name"])
         return typing.cast(aws_cdk.core.CfnMapping, jsii.invoke(self, "getMapping", [mapping_name]))
 
@@ -573,7 +589,9 @@ class CfnInclude(
         :param logical_id: the ID of the stack to retrieve, as it appears in the template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_nested_stack)
+            def stub(logical_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast("IncludedNestedStack", jsii.invoke(self, "getNestedStack", [logical_id]))
 
@@ -589,7 +607,9 @@ class CfnInclude(
         :param logical_id: the name of the output to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_output)
+            def stub(logical_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(aws_cdk.core.CfnOutput, jsii.invoke(self, "getOutput", [logical_id]))
 
@@ -605,7 +625,9 @@ class CfnInclude(
         :param parameter_name: the name of the parameter to retrieve.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_parameter)
+            def stub(parameter_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument parameter_name", value=parameter_name, expected_type=type_hints["parameter_name"])
         return typing.cast(aws_cdk.core.CfnParameter, jsii.invoke(self, "getParameter", [parameter_name]))
 
@@ -628,7 +650,9 @@ class CfnInclude(
         :param logical_id: the logical ID of the resource in the CloudFormation template file.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_resource)
+            def stub(logical_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         return typing.cast(aws_cdk.core.CfnResource, jsii.invoke(self, "getResource", [logical_id]))
 
@@ -644,7 +668,9 @@ class CfnInclude(
         :param rule_name: the name of the Rule in the CloudFormation template.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.get_rule)
+            def stub(rule_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument rule_name", value=rule_name, expected_type=type_hints["rule_name"])
         return typing.cast(aws_cdk.core.CfnRule, jsii.invoke(self, "getRule", [rule_name]))
 
@@ -674,7 +700,16 @@ class CfnInclude(
         :return: the same {@link IncludedNestedStack} object that {@link getNestedStack} returns for this logical ID
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnInclude.load_nested_stack)
+            def stub(
+                logical_id: builtins.str,
+                *,
+                template_file: builtins.str,
+                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                preserve_logical_ids: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument logical_id", value=logical_id, expected_type=type_hints["logical_id"])
         nested_stack_props = CfnIncludeProps(
             template_file=template_file,
@@ -726,7 +761,15 @@ class CfnIncludeProps:
             )
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CfnIncludeProps.__init__)
+            def stub(
+                *,
+                template_file: builtins.str,
+                load_nested_stacks: typing.Optional[typing.Mapping[builtins.str, typing.Union[CfnIncludeProps, typing.Dict[str, typing.Any]]]] = None,
+                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Any]] = None,
+                preserve_logical_ids: typing.Optional[builtins.bool] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
             check_type(argname="argument load_nested_stacks", value=load_nested_stacks, expected_type=type_hints["load_nested_stacks"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
@@ -840,7 +883,13 @@ class IncludedNestedStack:
             child_template = included_child_stack.included_template
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IncludedNestedStack.__init__)
+            def stub(
+                *,
+                included_template: CfnInclude,
+                stack: aws_cdk.core.NestedStack,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument included_template", value=included_template, expected_type=type_hints["included_template"])
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         self._values: typing.Dict[str, typing.Any] = {
